package com.digiwin.athena.app.ptc.service.production;

import com.alibaba.fastjson.TypeReference;
import com.alibaba.nacos.common.utils.StringUtils;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.digiwin.app.container.exceptions.DWBusinessException;
import com.digiwin.app.service.DWEAIResult;
import com.digiwin.athena.app.infra.common.enums.TabStatusEnums;
import com.digiwin.athena.app.ptc.infra.entity.ProductionDetailsEntity;
import com.digiwin.athena.app.ptc.infra.service.ProductionDetailsService;
import com.digiwin.athena.opt.common.eai.EAIRequest;
import com.digiwin.athena.opt.common.eai.service.AbsEAIService;
import com.digiwin.athena.opt.common.security.SecurityUtil;
import lombok.extern.log4j.Log4j2;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @auther: zhenggl
 * @date: 2023/9/12
 */
@Service
@Log4j2
public class ProductionTaskGetEAIService extends AbsEAIService {

    @Resource
    private ProductionDetailsService productionDetailsService;

    @Override
    public String getServiceName() {
        return ProductionUtil.PRODUCTION_TASK_GET;
    }

    @Override
    public DWEAIResult execute(Map<String, String> headers, String messageBody) throws Exception {
        //根据bk获取数据
        EAIRequest eaiRequest = EAIRequest.build(messageBody);
        List<ProductionDetailsEntity> productionDetailsEntities = eaiRequest.getObject("get_data", new TypeReference<List<ProductionDetailsEntity>>() {});

        for (ProductionDetailsEntity productionDetailsEntity : productionDetailsEntities) {
            if (StringUtils.isEmpty(productionDetailsEntity.getWorkNo())){
                throw new DWBusinessException("缺少必填参数");
            }
        }

        LambdaQueryWrapper<ProductionDetailsEntity> lmq = new LambdaQueryWrapper<>();
        List<String> woNoList = productionDetailsEntities.stream().map(ProductionDetailsEntity::getWorkNo).collect(Collectors.toList());
        lmq.eq(ProductionDetailsEntity::getTenantSid,SecurityUtil.getUserProfile().getTenantSid());
        lmq.eq(ProductionDetailsEntity::getProductionStatus, TabStatusEnums.PENDING.getValue());
        lmq.in(ProductionDetailsEntity::getWorkNo,woNoList);
        List<ProductionDetailsEntity> list = productionDetailsService.list(lmq);


        return buildOK("query_result",list);
    }
}
