package com.digiwin.athena.app.ptc.service.receivables;

import com.alibaba.fastjson.TypeReference;
import com.alibaba.nacos.common.utils.StringUtils;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.digiwin.app.container.exceptions.DWBusinessException;
import com.digiwin.app.service.DWEAIResult;
import com.digiwin.athena.app.infra.common.enums.TabStatusEnums;
import com.digiwin.athena.app.ptc.infra.entity.CollectionDetailEntity;
import com.digiwin.athena.app.ptc.infra.service.CollectionDetailService;
import com.digiwin.athena.opt.common.eai.EAIRequest;
import com.digiwin.athena.opt.common.eai.service.AbsEAIService;
import com.digiwin.athena.opt.common.security.SecurityUtil;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * @auther: zhenggl
 * @date: 2023/9/12
 */
public class ReceivablesTaskUpdateEAIService extends AbsEAIService {

    @Resource
    private CollectionDetailService collectionDetailService;

    @Override
    public String getServiceName() {
        return ReceivablesUtil.RECEIVABLES_TASK_UPDATE;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public DWEAIResult execute(Map<String, String> headers, String messageBody) throws Exception {
        //根据bk更新状态为已完成
        EAIRequest eaiRequest = EAIRequest.build(messageBody);
        List<CollectionDetailEntity> collectionDetailEntities = eaiRequest.getObject("get_data", new TypeReference<List<CollectionDetailEntity>>() {});

        for (CollectionDetailEntity collectionDetailEntity : collectionDetailEntities) {
            if (StringUtils.isEmpty(collectionDetailEntity.getSalesOrder())||StringUtils.isEmpty(collectionDetailEntity.getSalesOrderNumber())){
                throw new DWBusinessException("缺少必要参数");
            }
        }

        LambdaUpdateWrapper<CollectionDetailEntity> ump = new LambdaUpdateWrapper<>();
        ump.set(CollectionDetailEntity::getStatus, TabStatusEnums.COMPLETED.getValue());
        ump.eq(CollectionDetailEntity::getTenantSid, SecurityUtil.getUserProfile().getTenantSid());
        ump.and(queryWrapperInner -> {
                    for (CollectionDetailEntity collectionDetailEntity : collectionDetailEntities) {
                        queryWrapperInner.or(
                                wrapper -> wrapper
                                        .eq(CollectionDetailEntity::getSalesOrder, collectionDetailEntity.getSalesOrder())
                                        .eq(CollectionDetailEntity::getSalesOrderNumber, collectionDetailEntity.getSalesOrderNumber())
                        );
                    }
                }
        );
        collectionDetailService.update(ump);

        return buildOK("query_result",collectionDetailEntities);
    }
}
